Documentation
¶
Index ¶
- func FindHashtag(slice []Hashtag, val string) (int, bool)
- func FindUrl(slice []URL) (int, bool)
- func TwitterWebhook(w http.ResponseWriter, r *http.Request)
- type CRC
- type Entities
- type ExtendedTweet
- type Hashtag
- type QuotedStatus
- type QuotedStatusPermalink
- type SendMessage
- type Tweet
- type TweetCreateEvent
- type URL
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindHashtag ¶
FindHashtag takes a slice and looks for an element in it. If found it will return it's key, otherwise it will return -1 and a bool of false.
func FindUrl ¶
FindUrl takes a slice and looks for an element in it. If found it will return it's key, otherwise it will return -1 and a bool of false.
func TwitterWebhook ¶
func TwitterWebhook(w http.ResponseWriter, r *http.Request)
Types ¶
type Entities ¶
type Entities struct {
Urls []URL `json:"urls"`
UserMentions []interface{} `json:"user_mentions"`
Symbols []interface{} `json:"symbols"`
}
type ExtendedTweet ¶
type QuotedStatus ¶
type QuotedStatus struct {
CreatedAt string `json:"created_at"`
ID float64 `json:"id"`
IDStr string `json:"id_str"`
Text string `json:"text"`
Truncated bool `json:"truncated"`
IsQuoteStatus bool `json:"is_quote_status"`
QuoteCount int64 `json:"quote_count"`
ReplyCount int64 `json:"reply_count"`
RetweetCount int64 `json:"retweet_count"`
FavoriteCount int64 `json:"favorite_count"`
Entities Entities `json:"entities"`
ExtendedTweet *ExtendedTweet `json:"extended_tweet,omitempty"`
}
type QuotedStatusPermalink ¶
type SendMessage ¶
type Tweet ¶
type Tweet struct {
ForUserID string `json:"for_user_id"`
TweetCreateEvents []TweetCreateEvent `json:"tweet_create_events"`
}
type TweetCreateEvent ¶
type TweetCreateEvent struct {
CreatedAt string `json:"created_at"`
ID float64 `json:"id"`
IDStr string `json:"id_str"`
Text string `json:"text"`
Truncated bool `json:"truncated"`
QuotedStatusID float64 `json:"quoted_status_id"`
QuotedStatusIDStr string `json:"quoted_status_id_str"`
QuotedStatus QuotedStatus `json:"quoted_status"`
QuotedStatusPermalink QuotedStatusPermalink `json:"quoted_status_permalink"`
Entities Entities `json:"entities"`
Favorited bool `json:"favorited"`
Retweeted bool `json:"retweeted"`
TimestampMS string `json:"timestamp_ms"`
}
Click to show internal directories.
Click to hide internal directories.